/*
 * Copyright (C) 2018 IBM, Inc.
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package k8s

import (
	"fmt"

	"github.com/skydive-project/skydive/topology/graph"

	"k8s.io/api/core/v1"
	"k8s.io/client-go/kubernetes"
)

type persistentVolumeClaimHandler struct {
	DefaultResourceHandler
}

func (h *persistentVolumeClaimHandler) IsTopLevel() bool {
	return true
}

func (h *persistentVolumeClaimHandler) Dump(obj interface{}) string {
	pvc := obj.(*v1.PersistentVolumeClaim)
	return fmt.Sprintf("persistentvolumeclaim{Name: %s}", pvc.GetName())
}

func (h *persistentVolumeClaimHandler) Map(obj interface{}) (graph.Identifier, graph.Metadata) {
	pvc := obj.(*v1.PersistentVolumeClaim)
	m := newMetadata("persistentvolumeclaim", pvc.Namespace, pvc.GetName(), pvc)
	m.SetFieldAndNormalize("AccessModes", pvc.Spec.AccessModes)
	m.SetFieldAndNormalize("VolumeName", pvc.Spec.VolumeName)             // FIXME: replace by link to PersistentVolume
	m.SetFieldAndNormalize("StorageClassName", pvc.Spec.StorageClassName) // FIXME: replace by link to StorageClass
	m.SetFieldAndNormalize("VolumeMode", pvc.Spec.VolumeMode)
	m.SetFieldAndNormalize("Status", pvc.Status.Phase)
	return graph.Identifier(pvc.GetUID()), m
}

func newPersistentVolumeClaimProbe(clientset *kubernetes.Clientset, g *graph.Graph) Subprobe {
	return NewResourceCache(clientset.CoreV1().RESTClient(), &v1.PersistentVolumeClaim{}, "persistentvolumeclaims", g, &persistentVolumeClaimHandler{})
}
